@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: includes.php 19747 2012-11-29 13:15:33Z moyo $
+ * @version $Id: includes.php 21152 2013-06-20 06:21:38Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -83,6 +83,13 @@ if (isset($_GET)) {
    $_GET = array_map(array('Toolbox','addslashes_deep'), $_GET);
    $_GET = array_map(array('Toolbox', 'clean_cross_side_scripting_deep'), $_GET);
 }
+if (isset($_REQUEST)) {
+   if (Toolbox::get_magic_quotes_gpc()) {
+      $_REQUEST = array_map(array('Toolbox', 'stripslashes_deep'), $_REQUEST);
+   }
+   $_REQUEST = array_map(array('Toolbox','addslashes_deep'), $_REQUEST);
+   $_REQUEST = array_map(array('Toolbox', 'clean_cross_side_scripting_deep'), $_REQUEST);
+}
 
 // Mark if Header is loaded or not :
 $HEADER_LOADED=false;
