@@ -1,10 +1,10 @@
 <?php
 
 /*
- * @version $Id: log.class.php 19130 2012-08-22 14:33:50Z remi $
+ * @version $Id: log.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -109,7 +109,7 @@ class Log extends CommonDBTM {
       }
       // needed to have  $SEARCHOPTION
       list($real_type, $real_id) = $item->getLogTypeID();
-      // toolbox::logDebug("constructHistory:", $item->getType(), $real_type, $real_id, $oldvalues);
+       //toolbox::logDebug("constructHistory:", $item->getType(), $real_type, $real_id, $oldvalues);
 
       $searchopt = Search::getOptions($real_type);
 
@@ -167,10 +167,14 @@ class Log extends CommonDBTM {
                   if ($val2['table'] != 'glpi_complete_entities'
                      && $val2["table"] != 'glpi_auth_tables') {
                      $changes = array($id_search_option,
-                                      addslashes(Dropdown::getDropdownName($val2["table"],
-                                                                           $oldval)),
-                                      addslashes(Dropdown::getDropdownName($val2["table"],
-                                                                           $values[$key])));
+                                      addslashes(sprintf('%1$s (%2$s)',
+                                                        Dropdown::getDropdownName($val2["table"],
+                                                                                  $oldval),
+                                                        $oldval)),
+                                      addslashes(sprintf('%1$s (%2$s)',
+                                                         Dropdown::getDropdownName($val2["table"],
+                                                                                   $values[$key]),
+                                                          $values[$key])));
                   }
                }
                break;
