@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: problem.class.php 19681 2012-11-21 10:02:21Z moyo $
+ * @version $Id: problem.class.php 20130 2013-02-04 16:55:15Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -114,7 +114,7 @@ class Problem extends CommonITILObject {
    **/
    function canViewItem() {
 
-      if (!Session::haveAccessToEntity($this->getEntityID())) {
+      if (!Session::haveAccessToEntity($this->getEntityID(), $this->isRecursive())) {
          return false;
       }
       return (Session::haveRight('show_all_problem', 1)
@@ -337,7 +337,7 @@ class Problem extends CommonITILObject {
       if (((isset($input["_users_id_assign"]) && $input["_users_id_assign"]>0)
            || (isset($input["_groups_id_assign"]) && $input["_groups_id_assign"]>0)
            || (isset($input["suppliers_id_assign"]) && $input["suppliers_id_assign"]>0))
-          && $input["status"]=="new") {
+          && in_array($input['status'], $this->getNewStatusArray())) {
 
          $input["status"] = "assign";
       }
@@ -642,6 +642,16 @@ class Problem extends CommonITILObject {
       return $tab;
    }
 
+   /**
+    * Get the ITIL object new status list
+    *
+    * @since version 0.83.8
+    *
+    * @return an array
+   **/
+   static function getNewStatusArray() {
+      return array('new', 'accepted');
+   }
 
    /**
     * Get the ITIL object assign, plan or accepted status list
