@@ -2,10 +2,10 @@
 
 
 /*
- * @version $Id: software.class.php 19244 2012-09-11 18:17:25Z remi $
+ * @version $Id: software.class.php 20972 2013-05-21 07:29:11Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -354,6 +354,11 @@ class Software extends CommonDBTM {
       // Only use for History (not by search Engine)
       $tab = array();
 
+
+      $licjoin                   = array('jointype'  => 'child',
+                                         'condition' => getEntitiesRestrictRequest(' AND', "NEWTABLE",
+                                                                                   '', '', true));
+
       $tab[1]['table']         = $this->getTable();
       $tab[1]['field']         = 'name';
       $tab[1]['name']          = $LANG['common'][16];
@@ -367,12 +372,12 @@ class Software extends CommonDBTM {
       $tab[2]['massiveaction'] = false;
 
       $tab+=Location::getSearchOptionsToAdd();
-
+      
       $tab[7]['table']         = 'glpi_softwarelicenses';
       $tab[7]['field']         = 'name';
       $tab[7]['name']          = $LANG['common'][19];
       $tab[7]['massiveaction'] = false;
-      $tab[7]['joinparams']    = array('jointype' => 'child');
+      $tab[7]['joinparams']    = $licjoin;
 
       $tab[16]['table']    = $this->getTable();
       $tab[16]['field']    = 'comment';
@@ -491,21 +496,21 @@ class Software extends CommonDBTM {
       $tab[160]['name']          = $LANG['common'][16]." - ".$LANG['software'][11];
       $tab[160]['forcegroupby']  = true;
       $tab[160]['massiveaction'] = false;
-      $tab[160]['joinparams']    = array('jointype' => 'child');
+      $tab[160]['joinparams']    = $licjoin;
 
       $tab[161]['table']         = 'glpi_softwarelicenses';
       $tab[161]['field']         = 'serial';
       $tab[161]['name']          = $LANG['common'][19];
       $tab[161]['forcegroupby']  = true;
       $tab[161]['massiveaction'] = false;
-      $tab[161]['joinparams']    = array('jointype' => 'child');
+      $tab[161]['joinparams']    = $licjoin;
 
       $tab[162]['table']         = 'glpi_softwarelicenses';
       $tab[162]['field']         = 'otherserial';
       $tab[162]['name']          = $LANG['common'][20];
       $tab[162]['forcegroupby']  = true;
       $tab[162]['massiveaction'] = false;
-      $tab[162]['joinparams']    = array('jointype' => 'child');
+      $tab[162]['joinparams']    = $licjoin;
 
       $tab[163]['table']         = 'glpi_softwarelicenses';
       $tab[163]['field']         = 'number';
@@ -514,7 +519,7 @@ class Software extends CommonDBTM {
       $tab[163]['usehaving']     = true;
       $tab[163]['datatype']      = 'number';
       $tab[163]['massiveaction'] = false;
-      $tab[163]['joinparams']    = array('jointype' => 'child');
+      $tab[163]['joinparams']    = $licjoin;
 
       $tab[164]['table']         = 'glpi_softwarelicensetypes';
       $tab[164]['field']         = 'name';
@@ -523,7 +528,7 @@ class Software extends CommonDBTM {
       $tab[164]['massiveaction'] = false;
       $tab[164]['joinparams']    = array('beforejoin'
                                            => array('table'      => 'glpi_softwarelicenses',
-                                                    'joinparams' => array('jointype' => 'child')));
+                                                    'joinparams' => $licjoin));
 
       $tab[165]['table']         = 'glpi_softwarelicenses';
       $tab[165]['field']         = 'comment';
@@ -531,7 +536,7 @@ class Software extends CommonDBTM {
       $tab[165]['forcegroupby']  = true;
       $tab[165]['datatype']      = 'text';
       $tab[165]['massiveaction'] = false;
-      $tab[165]['joinparams']    = array('jointype' => 'child');
+      $tab[165]['joinparams']    = $licjoin;
 
       $tab[166]['table']         = 'glpi_softwarelicenses';
       $tab[166]['field']         =  'expire';
@@ -539,7 +544,7 @@ class Software extends CommonDBTM {
       $tab[166]['forcegroupby']  = true;
       $tab[166]['datatype']      = 'date';
       $tab[166]['massiveaction'] = false;
-      $tab[166]['joinparams']    = array('jointype' => 'child');
+      $tab[166]['joinparams']    = $licjoin;
 
       return $tab;
    }
