@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: toolbox.class.php 19692 2012-11-21 12:06:35Z moyo $
+ * @version $Id: toolbox.class.php 21171 2013-06-23 14:00:08Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2012 by the INDEPNET Development Team.
+ Copyright (C) 2003-2013 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -283,7 +283,7 @@ class Toolbox {
        $result .= $char;
      }
 
-     return $result;
+     return Toolbox::unclean_cross_side_scripting_deep($result);
    }
 
 
@@ -1771,11 +1771,41 @@ class Toolbox {
     * Clean integer value (strip all chars not - and spaces )
     *
     * @param $integer string: integer string
-    * @since versin 0.83.5
+    * @since version 0.83.5
     * @return clean integer
    **/
    static function cleanInteger($integer) {
       return preg_replace("/[^0-9-]/", "", $integer);
    }
+
+   /**
+    * Prepare array passed on an input form
+    *
+    * @param $value array: passed array
+    * @since version 0.83.91
+    * @return string encoded array
+   **/
+   static function prepareArrayForInput($value) {
+      return base64_encode(json_encode($value));
+   }
+
+   /**
+    * Decode array passed on an input form
+    *
+    * @param $value string: encoded value
+    * @since version 0.83.91
+    * @return string decoded array
+   **/
+   static function decodeArrayFromInput($value) {
+      if ($dec = base64_decode($value)) {
+         if ($ret = json_decode($dec,true)) {
+            return $ret;
+         }
+      }
+      return array();
+   }
+   
+
+   
 }
 ?>
\ No newline at end of file
